<?php

    if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
    
    class WPH_module_general_security_header_expect_ct extends WPH_module_component
        {
            
            private $headers = array ();
            
            function get_component_title()
                {
                    return "Expect CT";
                }
                                    
            function get_module_component_settings()
                {
                    
                    $this->component_settings[]                  =   array(
                                                                    'id'            =>  'expect_ct',
                                                                    'label'         =>  __('Expect CT',    'wp-hide-security-enhancer'),
                                                                    
                                                                    'help'          =>  array(
                                                                                                'title'                     =>  __('Help',    'wp-hide-security-enhancer') . ' - ' . __('Expect-CT',    'wp-hide-security-enhancer'),
                                                                                                'description'               =>  __("Allows sites to opt in to reporting and/or enforcement of Certificate Transparency requirements, which prevents the use of misissued certificates for that site from going unnoticed. When a site enables the Expect-CT header, they are requesting that Chrome check that any certificate for that site appears in public CT logs.",    'wp-hide-security-enhancer') .
                                                                                                                                
                                                                                                                                "<br /><br />" . __("Directives:",    'wp-hide-security-enhancer') .
                                                                                                                                "<br /><b>max-age</b> - "  . __("The number of seconds after reception of the Expect-CT header field during which the user agent should regard the host of the received message as a known Expect-CT host. <br />If a cache receives a value greater than it can represent, or if any of its subsequent calculations overflows, the cache will consider this value to be either 2,147,483,648 (2^31) or the greatest positive integer it can represent.",    'wp-hide-security-enhancer') .
                                                                                                                                "<br /><b>report-uri=\"&#60;uri&#62;\"</b> - "  . __("The URI where the user agent should report Expect-CT failures.<br />When present with the enforce directive, the configuration is referred to as an \"enforce-and-report\" configuration, signalling to the user agent both that compliance to the Certificate Transparency policy should be enforced and that violations should be reported.",    'wp-hide-security-enhancer') .
                                                                                                                                "<br /><b>enforce</b> - "  . __("Signals to the user agent that compliance with the Certificate Transparency policy should be enforced (rather than only reporting compliance) and that the user agent should refuse future connections that violate its Certificate Transparency policy.<br />When both the enforce directive and the report-uri directive are present, the configuration is referred to as an \"enforce-and-report\" configuration, signalling to the user agent both that compliance to the Certificate Transparency policy should be enforced and that violations should be reported.",    'wp-hide-security-enhancer') ,
                                                                                                'option_documentation_url'  =>  'https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Expect-CT'
                                                                                                ),
                                                                    
                                                                    'input_type'    =>  'custom',
                                                                                                 
                                                                    'module_option_html_render' =>  array( $this, '_module_option_html' ),
                                                                    'module_option_processing'  =>  array( $this, '_module_option_processing' ),
                                                                      
                                                                    ); 
                  
                                                                    
                    return $this->component_settings;   
                }
            
            function _get_default_options()
                {
                    
                    $options    =   array ( 
                                            'enabled'           =>  'no',
                                            'max-age'           =>  '',
                                            'report-uri'        =>  '',
                                            'enforce'           =>  ''
                                            );
                    return $options;
                }
                
            function _init_expect_ct( $saved_field_data )
                {
                    
                }
            
               
            function _module_option_html( $module_settings )
                {
                    
                    $values =   $this->wph->functions->get_site_module_saved_value( $module_settings['id'],  $this->wph->functions->get_blog_id_setting_to_use(), 'display');
                    $module_settings =   shortcode_atts ( $this->_get_default_options(), (array)$values )        
                    
                    ?>
                        <div class="row xspacer header">
                            <p><?php _e('Enable Header',    'wp-hide-security-enhancer') ?></p>
                            <fieldset>
                                <label>
                                    <input type="radio" class="radio" value="no" name="enabled" <?php if ( $module_settings['enabled'] == 'no' ) { ?>checked="checked"<?php } ?>> <span>No</span>
                                </label>
                                <label>
                                    <input type="radio" class="radio" value="yes" name="enabled" <?php if ( $module_settings['enabled'] == 'yes' ) { ?>checked="checked"<?php } ?>> <span>Yes</span>
                                </label>                                                                
                            </fieldset>
                        </div>
                       
                        <p><b><?php _e( 'report-uri',    'wp-hide-security-enhancer') ?></b></p>
                        <div class="row group">
                            <fieldset>
                                <label>
                                    <select name="max-age">
                                        <option value="0" <?php if ( $module_settings['max-age'] == '0' ) { ?>selected="selected"<?php } ?>>0 ( Remove the cached HSTS Policy )</option>
                                        <option value="3600" <?php if ( $module_settings['max-age'] == '3600' ) { ?>selected="selected"<?php } ?>>1 <?php _e('hour',    'wp-hide-security-enhancer') ?></option>
                                        <option value="86400" <?php if ( $module_settings['max-age'] == '86400' ) { ?>selected="selected"<?php } ?>>1 <?php _e('day',    'wp-hide-security-enhancer') ?></option>
                                        <option value="604800" <?php if ( $module_settings['max-age'] == '604800' ) { ?>selected="selected"<?php } ?>>7 <?php _e('days',    'wp-hide-security-enhancer') ?></option>
                                        <option value="2592000" <?php if ( $module_settings['max-age'] == '2592000' ) { ?>selected="selected"<?php } ?>>30 <?php _e('days',    'wp-hide-security-enhancer') ?></option>
                                        <option value="7776000" <?php if ( $module_settings['max-age'] == '7776000' ) { ?>selected="selected"<?php } ?>>90 <?php _e('days',    'wp-hide-security-enhancer') ?></option>
                                        <option value="31536000" <?php if ( $module_settings['max-age'] == '31536000' ) { ?>selected="selected"<?php } ?>>1 <?php _e('year',    'wp-hide-security-enhancer') ?></option>
                                        <option value="63072000" <?php if ( $module_settings['max-age'] == '63072000' ) { ?>selected="selected"<?php } ?>>2 <?php _e('years',    'wp-hide-security-enhancer') ?></option>    
                                    </select> <span>max-age</span>
                                </label>                                                                
                            </fieldset>
                        </div>
                        
                        <p><b><?php _e( 'report-uri',    'wp-hide-security-enhancer') ?></b></p>
                        <div class="row group">
                            <fieldset>
                                <input name="report-uri" type="text" value="<?php if ( isset ( $module_settings['report-uri'] ) && ! empty ( $module_settings['report-uri'] ) ) { echo htmlspecialchars ( $module_settings['report-uri'] ); } ?>">
                            </fieldset>
                        </div>
                       
                        <p><b><?php _e( 'enforce',    'wp-hide-security-enhancer') ?></b></p>
                        <div class="row group">
                            <fieldset>
                                <input id="option-enforce" name="enforce" type="checkbox" value="enforce" <?php if ( isset ( $module_settings['enforce'] ) && ! empty ( $module_settings['enforce'] ) ) { ?>checked="checked"<?php } ?>> <label for="option-enforce"><?php _e ( 'Yes',  'wp-hide-security-enhancer') ?></label>
                            </fieldset>
                        </div>
                                             
                        
                    <?php
                }
                
                
            function _module_option_processing( $field_name )
                {
                    
                    $results            =   array();
                    
                    $module_settings =   shortcode_atts ( $this->_get_default_options(), array() );
                    foreach ( $module_settings   as  $setting_name  =>  $setting_value )
                        {
                            if ( ! isset ( $_POST[ $setting_name ] ) )
                                continue;
                            
                            if ( is_array ( $_POST[ $setting_name ] ) )
                                {
                                    $values  =   preg_replace( '/[^a-zA-Z0-9-_\*\:\.]/m' , '', $_POST[ $setting_name ] );
                                    
                                    $module_settings[ $setting_name ]   =   array_filter( $values );
                                }
                                else
                                {    
                                    $value  =   preg_replace( '/[^a-zA-Z0-9-_\:\.]/m' , '', $_POST[ $setting_name ] );
                                    if ( empty ( $value ) )
                                        continue;
                                        
                                    $module_settings[ $setting_name ]   =   $value;
                                }
                        }
                                        
                    $results['value']   =   $module_settings;
                       
                    return $results;
                    
                }
                
                    
            function _callback_saved_expect_ct( $saved_field_data )
                {
                    
                    if ( empty ( $saved_field_data ) ||  ! is_array ( $saved_field_data ) || ! isset ( $saved_field_data['enabled'] ) || $saved_field_data['enabled']   ==  'no' )
                        return FALSE;
                        
                    $processing_response    =   array();
                                                         
                    $rewrite_line                            =  '';
                    
                    $all_options    =   $saved_field_data;
                    unset ( $all_options['enabled'] );
                    
                    foreach ( $all_options  as $option_key  =>  $option )
                        {
                            if ( ! empty ( $option ) )
                                {
                                    $rewrite_line    .=  "$option_key=" .  $option . ';';
                                    continue;
                                }
                        }
                    
                    $rewrite_line    =   trim ( $rewrite_line );
                    $rewrite_line    =   rtrim ( $rewrite_line, ';' );
                                        
                    if($this->wph->server_htaccess_config   === TRUE)                               
                        {
                            $rewrite    =  "\n" . '        Header set Expect-CT "' . $rewrite_line . '"';
                            
                            $processing_response['type']    =   'header';                            
                        }
                        
                    if( $this->wph->server_nginx_config   === TRUE )
                        {  
                            $rewrite_block        =   array();
                            $rewrite_list   =   array();
                            $rewrite_rules  =   array();
                            
                            $rewrite_list['type']        =   'header';
                            $rewrite_list['description'] =   '';
                            
                            $rewrite_data  =   '         add_header Expect-CT "' . $rewrite_line . '";';
                            
                            $rewrite_rules[]            =   $rewrite_data;
                            $rewrite_list['data']       =   $rewrite_rules;
                            
                            $rewrite[]  =   $rewrite_list;
                               
                        }
                    
                    $processing_response['rewrite'] =   $rewrite;
                                      
                    return  $processing_response;
                    
                } 
            

        }
?>